@@ -2,9 +2,9 @@
 
 //! *See the [Arb documentation](https://arblib.org/).
 
-use flint_sys::deps::*;
-use crate::acb::{acb_struct, acb_ptr, acb_srcptr};
+use crate::acb::{acb_ptr, acb_srcptr, acb_struct};
 use crate::acb_poly::acb_poly_struct;
+use flint_sys::deps::*;
 
 extern "C" {
     pub fn acb_elliptic_k(k: *mut acb_struct, m: *mut acb_struct, prec: mp_limb_signed_t);
